==> mx-bootrepair_19.5.tar.xz: mx-bootrepair-19.5/translations/mx-bootrepair_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as root.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mxbootrepair</name>
    <message>
        <location filename="../mxbootrepair.ui" line="20"/>
        <location filename="../mxbootrepair.cpp" line="442"/>
        <source>MX Boot Repair</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="123"/>
        <location filename="../mxbootrepair.cpp" line="375"/>
        <source>Select Boot Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="141"/>
        <source>Master Boot Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="144"/>
        <source>MBR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="147"/>
        <location filename="../mxbootrepair.ui" line="417"/>
        <source>Alt+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="169"/>
        <source>Root (Partition Boot Record)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="172"/>
        <location filename="../mxbootrepair.cpp" line="377"/>
        <source>root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="223"/>
        <location filename="../mxbootrepair.cpp" line="376"/>
        <source>Install on:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="242"/>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="264"/>
        <source>Select /boot location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="277"/>
        <source>EFI System Partition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="280"/>
        <source>ESP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="407"/>
        <source>About this application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="410"/>
        <source>About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="459"/>
        <source>Display help </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="462"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="469"/>
        <source>Alt+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="510"/>
        <source>Cancel any changes then quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="513"/>
        <location filename="../mxbootrepair.cpp" line="448"/>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="520"/>
        <source>Alt+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="539"/>
        <source>Apply any changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="542"/>
        <location filename="../mxbootrepair.cpp" line="75"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="93"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="108"/>
        <location filename="../mxbootrepair.cpp" line="131"/>
        <location filename="../mxbootrepair.cpp" line="161"/>
        <location filename="../mxbootrepair.cpp" line="263"/>
        <location filename="../mxbootrepair.cpp" line="297"/>
        <location filename="../mxbootrepair.cpp" line="415"/>
        <location filename="../mxbootrepair.cpp" line="422"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="109"/>
        <source>Could not mount </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="109"/>
        <source> on /boot/efi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="132"/>
        <location filename="../mxbootrepair.cpp" line="162"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="149"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="183"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="238"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="239"/>
        <source>You are going to write the content of </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="239"/>
        <source> to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="239"/>
        <source>

Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="240"/>
        <location filename="../mxbootrepair.cpp" line="293"/>
        <source>Yes</source>
        <translation>Da</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="240"/>
        <location filename="../mxbootrepair.cpp" line="293"/>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="244"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="264"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="291"/>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="292"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="298"/>
        <source>Process finished. Errors have occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="300"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="384"/>
        <source>Select GRUB location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="395"/>
        <source>Select Item to Back Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="402"/>
        <source>Select Item to Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="413"/>
        <source>Select backup file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="415"/>
        <location filename="../mxbootrepair.cpp" line="422"/>
        <source>No file was selected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="420"/>
        <source>Select MBR or PBR backup file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="441"/>
        <source>About MX Boot Repair</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="442"/>
        <source>Version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="444"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="446"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="447"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="469"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-bootrepair_19.8.tar.xz: mx-bootrepair-19.8/translations/mx-bootrepair_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as root.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mxbootrepair</name>
    <message>
        <location filename="../mxbootrepair.ui" line="20"/>
        <location filename="../mxbootrepair.cpp" line="443"/>
        <source>MX Boot Repair</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="123"/>
        <location filename="../mxbootrepair.cpp" line="376"/>
        <source>Select Boot Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="141"/>
        <source>Master Boot Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="144"/>
        <source>MBR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="147"/>
        <location filename="../mxbootrepair.ui" line="417"/>
        <source>Alt+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="169"/>
        <source>Root (Partition Boot Record)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="172"/>
        <location filename="../mxbootrepair.cpp" line="378"/>
        <source>root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="223"/>
        <location filename="../mxbootrepair.cpp" line="377"/>
        <source>Install on:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="242"/>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="264"/>
        <source>Select /boot location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="277"/>
        <source>EFI System Partition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="280"/>
        <source>ESP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="407"/>
        <source>About this application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="410"/>
        <source>About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="459"/>
        <source>Display help </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="462"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="469"/>
        <source>Alt+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="510"/>
        <source>Cancel any changes then quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="513"/>
        <location filename="../mxbootrepair.cpp" line="449"/>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="520"/>
        <source>Alt+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="539"/>
        <source>Apply any changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="542"/>
        <location filename="../mxbootrepair.cpp" line="76"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="94"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="109"/>
        <location filename="../mxbootrepair.cpp" line="132"/>
        <location filename="../mxbootrepair.cpp" line="162"/>
        <location filename="../mxbootrepair.cpp" line="264"/>
        <location filename="../mxbootrepair.cpp" line="298"/>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="110"/>
        <source>Could not mount </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="110"/>
        <source> on /boot/efi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="133"/>
        <location filename="../mxbootrepair.cpp" line="163"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="150"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="184"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="239"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="240"/>
        <source>You are going to write the content of </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="240"/>
        <source> to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="240"/>
        <source>

Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">Da</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">Ne</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="245"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="265"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="292"/>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="293"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="299"/>
        <source>Process finished. Errors have occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="301"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="385"/>
        <source>Select GRUB location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="396"/>
        <source>Select Item to Back Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="403"/>
        <source>Select Item to Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="414"/>
        <source>Select backup file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>No file was selected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="421"/>
        <source>Select MBR or PBR backup file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="442"/>
        <source>About MX Boot Repair</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="443"/>
        <source>Version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="446"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="447"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="448"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="470"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
